@@ -54,7 +54,8 @@ class RestApi:
 
         def handler(event, context):
             http_method = event['httpMethod']
-            is_detail = event.get('pathParameters', {}).get(self.detail_key) != None
+            path_parameters = event.get('pathParameters', {}) or {}
+            is_detail = path_parameters.get(self.detail_key) != None
             rest_function = self.get_method(http_method, is_detail)
             response = rest_function(event, context)
             self.decorate_response(response)
